==> asksuite-core-2.9.4.tgz: package/tracker.js <==
const request = require('request');


module.exports = function(config){

    const host =  config.INFOCHAT_DATA_SERVER;
    const BotmetricsMiddleware = {};

    BotmetricsMiddleware.receive = function (conversationId, message) {
        return  sendRequest('/conversationhistories/' + conversationId, message);
    };

    BotmetricsMiddleware.send = function (conversationId, message) {
        //   if (message) {
        return   sendRequest('/conversationhistories/' + conversationId, message);
        // }
    };

    BotmetricsMiddleware.updateData = function (conversationId, message) {
        return  sendRequest('/conversations/' + conversationId + '/userdata', message);
    };

    BotmetricsMiddleware.trackIntent = function (message) {
        return  sendRequest('/intentstracks', message);
    };

    BotmetricsMiddleware.sendEmailRequest = function (message) {
        return      sendRequest('/requests', message);
    };

    BotmetricsMiddleware.registerNewConversation = function (data) {
        // console.log("registrando new conversation");
        return sendRequest('/conversations', data);
    };

    function sendRequest(uri, data) {

        // if (process.env.NODE_ENV != 'dev') {

        return new Promise((resolve) => {

            console.log(host + uri);

            request.post({url: host + uri, json: data}, function (err, _resp, _body) {
                if (err) {
                    // console.log("############################erro")
                } else {
                    // console.log("###########################salvou")
                }

                resolve(_body);

                // console.log(body);
            });
        });

        // }
    }

    return BotmetricsMiddleware;
};

==> asksuite-core-2.13.1.tgz: package/tracker.js <==
const request = require('request');


module.exports = function(config){

    const host =  config.INFOCHAT_DATA_SERVER;
    const BotmetricsMiddleware = {};

    BotmetricsMiddleware.receive = function (conversationId, message) {
        return  sendRequest('/conversationhistories/' + conversationId, message);
    };

    BotmetricsMiddleware.send = function (conversationId, message, isTest = false) {
        //   if (message) {
        return isTest ? returnTestRequest() : sendRequest('/conversationhistories/' + conversationId, message);
        // }
    };

    BotmetricsMiddleware.updateData = function (conversationId, message) {
        return  sendRequest('/conversations/' + conversationId + '/userdata', message);
    };

    BotmetricsMiddleware.trackIntent = function (message, isTest = false) {
        return isTest ? returnTestRequest() : sendRequest('/intentstracks', message);
    };

    BotmetricsMiddleware.sendEmailRequest = function (message) {
        return sendRequest('/requests', message);
    };

    BotmetricsMiddleware.registerNewConversation = function (data, isTest = false) {
        return isTest ? returnTestRequest() : sendRequest('/conversations', data);
    };

    function returnTestRequest() {
        return Promise.resolve();
    }

    function sendRequest(uri, data) {

        // if (process.env.NODE_ENV != 'dev') {

        return new Promise((resolve) => {

            console.log(host + uri);

            request.post({url: host + uri, json: data}, function (err, _resp, _body) {
                if (err) {
                    // console.log("############################erro")
                } else {
                    // console.log("###########################salvou")
                }

                resolve(_body);

                // console.log(body);
            });
        });

        // }
    }

    return BotmetricsMiddleware;
};
